v0.2.2
======

- Fixed bug #2 that does not respond to first message from a buddy
- Added temporary fix for #2 related to Kqueue

v0.2.1
======

- Maintenance release
- Fixed broken README RST rendering on PyPI

v0.2.0
======

- Supported event handling based on watchdog
- Added message receive feature
- Introduced chat backend API
- Changed several methods of Adium class

v0.1.1
======

- Maintenance release.
- Fixed url to GitHub page to match that on PyPI

v0.1.0
======

- Initial release.
